/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.nachrichten.postfach.muk;

import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

import de.ozgcloud.apilib.file.OzgCloudFileService;
import de.ozgcloud.apilib.file.grpc.GrpcOzgCloudFileService;
import de.ozgcloud.apilib.file.grpc.OzgCloudFileMapper;
import de.ozgcloud.vorgang.grpc.binaryFile.BinaryFileServiceGrpc.BinaryFileServiceBlockingStub;
import de.ozgcloud.vorgang.grpc.binaryFile.BinaryFileServiceGrpc.BinaryFileServiceStub;
import net.devh.boot.grpc.client.inject.GrpcClient;

@Configuration
public class MukPostfachConfiguration {

	public static final String OZG_CLOUD_FILE_SERVICE_NAME = "mukPostfach_OzgCloudFileService";

	public static final String GRPC_FILE_MANAGER_NAME = "file-manager";

	public static final String MUK_POSTFACH_CLIENT_NAME = "OzgCloud_MukPostfach";

	@GrpcClient(GRPC_FILE_MANAGER_NAME)
	private BinaryFileServiceBlockingStub fileServiceBlockingStub;
	@GrpcClient(GRPC_FILE_MANAGER_NAME)
	private BinaryFileServiceStub fileServiceAsyncServiceStub;

	@Bean(OZG_CLOUD_FILE_SERVICE_NAME) // NOSONAR
	OzgCloudFileService grpcOzgCloudFileService(MukPostfachCallContextProvider contextProvider, OzgCloudFileMapper mapper) {
		return new GrpcOzgCloudFileService(fileServiceBlockingStub, fileServiceAsyncServiceStub, contextProvider, mapper);
	}
}
