/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.nachrichten.postfach.muk.transfer;

import java.io.BufferedInputStream;
import java.io.OutputStream;

import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.stereotype.Service;

import de.ozgcloud.apilib.file.OzgCloudFile;
import de.ozgcloud.apilib.file.OzgCloudFileId;
import de.ozgcloud.apilib.file.OzgCloudFileService;
import de.ozgcloud.apilib.file.OzgCloudUploadFile;
import de.ozgcloud.nachrichten.postfach.muk.MukPostfachConfiguration;
import lombok.RequiredArgsConstructor;

@Service
@RequiredArgsConstructor
public class AttachmentService {
	@Qualifier(MukPostfachConfiguration.OZG_CLOUD_FILE_SERVICE_NAME) // NOSONAR
	private final OzgCloudFileService ozgCloudFileService;

	OzgCloudFile getCloudFile(String fileId) {
		return ozgCloudFileService.getFile(OzgCloudFileId.from(fileId));
	}

	void getFileContent(OzgCloudFileId fileId, OutputStream outputStream) {
		ozgCloudFileService.writeFileDataToStream(fileId, outputStream);
	}

	public OzgCloudFileId store(OzgCloudUploadFile attachment, BufferedInputStream dataStream) {
		return ozgCloudFileService.uploadFile(attachment, dataStream);
	}
}
